Documentation
¶
Index ¶
- Variables
- func GetBoltContent() []string
- func LoopRequest(d time.Duration, f func(key string), uniqueKey string)
- func LoopRequestFullSpeed(f func(key string), uniqueKey string)
- func MakeRequestWithRandomUpdate(uniqueKey string)
- func PutDatabaseItem(item *Item) error
- func ReportStats()
- func RunHttpServer()
- func StartDatabase()
- func WriteItem(item *Item)
- type CState
- type Item
- type OutboundRequest
- type State
- type States
- type Values
Constants ¶
This section is empty.
Variables ¶
var DB *bbolt.DB
Create an exported global variable to hold the database connection pool.
Functions ¶
func GetBoltContent ¶
func GetBoltContent() []string
TODO - get everything from the database, all k/v pairs GetBoltContent get everything in the database
func LoopRequest ¶
LoopRequest perform the loop
func LoopRequestFullSpeed ¶
func MakeRequestWithRandomUpdate ¶
func MakeRequestWithRandomUpdate(uniqueKey string)
MakeRequestWithRandomUpdate make out bound call
func PutDatabaseItem ¶
PutDatabaseItem performs verification of inbound requests against database state
func RunHttpServer ¶
func RunHttpServer()
RunHttpServer - executes the API that will be hit for the experiment
Types ¶
type OutboundRequest ¶
Click to show internal directories.
Click to hide internal directories.